"use strict";

exports.__esModule = true;
exports.DocumentsGraphqlTable = void 0;
var _react = _interopRequireWildcard(require("react"));
var _terminusdbReactTable = require("@terminusdb/terminusdb-react-table");
var _useTDBGraphqlQuery = require("../hook/useTDBGraphqlQuery");
var _reactBootstrap = require("react-bootstrap");
var _GraphqlQueryViewer = require("./GraphqlQueryViewer");
var _graphqlFormatter = require("graphql-formatter");
var _Accordion = _interopRequireDefault(require("react-bootstrap/Accordion"));
var _ri = require("react-icons/ri");
var _hi = require("react-icons/hi");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
//to be review
const DocumentsGraphqlTable = ({
  gqlQuery,
  apolloClient,
  tableConfig,
  type,
  onRowClick,
  onViewButtonClick,
  onEditButtonClick,
  onDeleteButtonClick,
  showGraphqlTab: _showGraphqlTab = true
}) => {
  if (!tableConfig) return '';
  const query = gqlQuery; //gql`${querystr}`
  const [advSearchFields, setAdvFields] = (0, _react.useState)(false);
  const [queryToDisplay, setQueryTodisplay] = (0, _react.useState)(false);
  if (!query) return "";
  const tablesColumnsConfig = tableConfig.tablesColumnsConfig[type] || [];
  const {
    setError,
    callGraphqlServer,
    error,
    changeOrders,
    changeLimits,
    changeFilters,
    setAdvancedFilters,
    orderBy,
    filterBy,
    queryFilters,
    queryOrders,
    limit,
    start,
    loading,
    rowCount,
    documentResults: data,
    extractedData,
    hiddenColumnsArr,
    setHiddenColumns
  } = (0, _useTDBGraphqlQuery.useTDBGraphqlQuery)(apolloClient, query, type, {
    limit: 10,
    start: 0,
    tableConfigObj: tablesColumnsConfig
  });
  let extractedResults = extractedData || [];
  (0, _react.useEffect)(() => {
    if (type) {
      callGraphqlServer(10, 0, {}, false);
      const queryStr = query.loc.source.body;
      setQueryTodisplay((0, _graphqlFormatter.format)(queryStr));
      setAdvFields(tableConfig.advancedSearchObj[type]);
    }
  }, [type]);
  function onRowClickCall(row) {
    if (onRowClick) {
      const rowTmp = row && row.original ? {
        label: row.original.name,
        id: row.original.fullID
      } : {};
      onRowClick(rowTmp);
    }
  }
  const deleteAction = (evt, row) => {
    evt.stopPropagation();
    if (onDeleteButtonClick) {
      const rowTmp = row && row.original ? {
        label: row.original.name,
        id: row.original.fullID
      } : {};
      onDeleteButtonClick(rowTmp);
    }
  };
  const viewAction = (evt, row) => {
    evt.stopPropagation();
    if (onViewButtonClick) {
      const rowTmp = row && row.original ? {
        label: row.original.name,
        id: row.original.fullID
      } : {};
      onViewButtonClick(rowTmp);
    }
  };
  const editAction = (evt, row) => {
    evt.stopPropagation();
    if (onEditButtonClick) {
      const rowTmp = row && row.original ? {
        label: row.original.name,
        id: row.original.fullID
      } : {};
      onEditButtonClick(rowTmp);
    }
  };
  const getActionButtons = props => {
    const invFullId = props.cell.row; //.original['id']
    //const name = cell.row.original['name']
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("span", {
      className: "d-flex justify-content-end mr-4"
    }, onViewButtonClick && /*#__PURE__*/_react.default.createElement(_reactBootstrap.Button, {
      variant: "success",
      size: "sm",
      className: "ml-3",
      title: `view document`,
      onClick: evt => viewAction(evt, invFullId)
    }, /*#__PURE__*/_react.default.createElement(_hi.HiOutlineDocument, null)), onEditButtonClick && /*#__PURE__*/_react.default.createElement(_reactBootstrap.Button, {
      variant: "success",
      size: "sm",
      className: "ml-3",
      title: `edit document`,
      onClick: evt => editAction(evt, invFullId)
    }, /*#__PURE__*/_react.default.createElement(_ri.RiEdit2Fill, null)), onDeleteButtonClick && /*#__PURE__*/_react.default.createElement(_reactBootstrap.Button, {
      variant: "danger",
      size: "sm",
      className: "ml-3",
      title: `delete document`,
      onClick: evt => deleteAction(evt, invFullId)
    }, /*#__PURE__*/_react.default.createElement(_ri.RiDeleteBin7Line, null))));
  };
  const makeConfig = () => {
    const actionsButttons = {
      Header: "",
      accessor: "__ACTIONS__",
      disableFilters: true,
      disableSortBy: true,
      id: "__ACTIONS__",
      renderer: getActionButtons
    };

    // to be review
    const tableConfigObj = {};
    tableConfigObj.columns = JSON.parse(JSON.stringify(tablesColumnsConfig));
    if (onDeleteButtonClick || onEditButtonClick || onViewButtonClick) {
      tableConfigObj.columns.push(actionsButttons);
    }
    if (onRowClickCall) {
      tableConfigObj.rowClick = onRowClickCall;
    }
    return tableConfigObj;
  };
  const tableConfigObj = (0, _react.useMemo)(() => makeConfig(), [tablesColumnsConfig]);
  const errorMessage = error && typeof error === "object" ? JSON.stringify(error, null, 2) : error;
  return /*#__PURE__*/_react.default.createElement("div", null, error && /*#__PURE__*/_react.default.createElement(_reactBootstrap.Alert, {
    onClose: () => setError(false),
    dismissible: true,
    className: "text-break",
    variant: "danger"
  }, "GraphQL query error ", /*#__PURE__*/_react.default.createElement("pre", {
    className: "pre--error"
  }, errorMessage), " "), advSearchFields && /*#__PURE__*/_react.default.createElement(_Accordion.default, {
    className: "mb-4"
  }, /*#__PURE__*/_react.default.createElement(_Accordion.default.Item, {
    eventKey: "0"
  }, /*#__PURE__*/_react.default.createElement(_Accordion.default.Header, null, "Advanced filter"), /*#__PURE__*/_react.default.createElement(_Accordion.default.Body, {
    className: "p-0"
  }, /*#__PURE__*/_react.default.createElement(_terminusdbReactTable.AdvancedSearch, {
    fields: advSearchFields,
    setFilter: setAdvancedFilters
  })))), loading && /*#__PURE__*/_react.default.createElement(_reactBootstrap.Container, {
    className: "loading-bar-align justify-content-center"
  }, /*#__PURE__*/_react.default.createElement(_reactBootstrap.ProgressBar, {
    message: `Loading ${type} ...`
  })), !loading && /*#__PURE__*/_react.default.createElement(_reactBootstrap.Tabs, {
    defaultActiveKey: "table",
    className: "mb-3"
  }, /*#__PURE__*/_react.default.createElement(_reactBootstrap.Tab, {
    eventKey: "table",
    title: "Result Table"
  }, !loading && Array.isArray(extractedResults) && /*#__PURE__*/_react.default.createElement(_terminusdbReactTable.TDBReactTable
  // dowloadConfig={{filename:"test.csv",headers:["Author","Commit ID"]}}
  , {
    result: extractedResults,
    freewidth: true,
    config: tableConfigObj,
    hiddenColumnsArr: hiddenColumnsArr,
    setHiddenColumns: setHiddenColumns,
    limit: limit,
    start: start,
    orderBy: orderBy,
    filterBy: filterBy,
    setFilters: changeFilters,
    setLimits: changeLimits,
    setOrder: changeOrders,
    loading: loading,
    totalRows: rowCount
  })), _showGraphqlTab && /*#__PURE__*/_react.default.createElement(_reactBootstrap.Tab, {
    eventKey: "graphql",
    title: "Graphql Query"
  }, /*#__PURE__*/_react.default.createElement("div", null, queryToDisplay && /*#__PURE__*/_react.default.createElement(_GraphqlQueryViewer.GraphqlQueryView, {
    queryFilters: queryFilters,
    queryOrders: queryOrders,
    start: start,
    limit: limit,
    queryToDisplay: queryToDisplay
  })))));
};
exports.DocumentsGraphqlTable = DocumentsGraphqlTable;