"use strict";

exports.__esModule = true;
exports.useTDBDocumentQuery = useTDBDocumentQuery;
var _react = _interopRequireWildcard(require("react"));
var _terminusdbClient = _interopRequireDefault(require("@terminusdb/terminusdb-client"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const WOQL = _terminusdbClient.default.WOQL;
function useTDBDocumentQuery(woqlClient, document, queryLimit, queryStart, order) {
  const [limit, setLimit] = (0, _react.useState)(queryLimit || 10);
  const [start, setStart] = (0, _react.useState)(queryStart || 0);
  const [orderBy, setOrderBy] = (0, _react.useState)(order || false);
  const [rowCount, setRowCount] = (0, _react.useState)(0);
  const [loading, setLoading] = (0, _react.useState)(false);
  const [loaded, setLoaded] = (0, _react.useState)(false);
  const [controlledRefresh, setControlledRefresh] = (0, _react.useState)(0);
  const [documentResults, setDocumentResults] = (0, _react.useState)(false);
  const [documentError, setDocumentError] = (0, _react.useState)(false);
  const controlledDocument = document;
  const changeOrder = ord => {
    if (JSON.stringify(orderBy) != JSON.stringify(ord)) {
      setOrderBy(ord);
      setStart(0);
    }
  };
  const changeLimits = (l, s) => {
    let ll = parseInt(l) || 0;
    let ss = parseInt(s) || 0;
    if (ll !== limit) {
      setLimit(ll);
    }
    if (ss !== start) setStart(ss);
  };
  const onRefresh = () => {
    setRefresh(controlledRefresh + 1);
  };

  //I prefer run the query directly and pass the new document
  //to be review
  //the result is the only things that trigger a refresh
  const updateDocument = () => {
    //setControlledDocument(document)
  };

  // we need the query result and the count query result
  const executeQuery = async () => {
    if (controlledDocument && woqlClient) {
      let params = {};
      setLoading(true);
      let tstart = Date.now();
      let db = woqlClient.db();
      params['type'] = controlledDocument;
      params['as_list'] = true;
      params['skip'] = start;
      params['count'] = limit;
      try {
        const response = await woqlClient.getDocument(params, db);
        const countResult = await executeCountQuery();
        setDocumentResults(response);
        setRowCount(countResult);
      } catch (error) {
        processErrorResult(error, tstart);
      } finally {
        setLoading(false);
      }
    }
  };
  const checkIfPrefix = id => {
    if (id.indexOf(":") > -1) {
      return id;
    }
    return "@schema:" + id;
  };
  const executeCountQuery = () => {
    const typeDoc = checkIfPrefix(document);
    let q = WOQL.count("v:Count", WOQL.triple("v:doc", "rdf:type", typeDoc));
    return woqlClient.query(q).then(cresult => {
      return cresult && cresult.bindings && cresult.bindings.length ? cresult.bindings[0]['Count']['@value'] : 0;
    });
  };

  /*
   * I have to review the error in interceptor
   */
  function processErrorResult(e, stime) {
    let response = {};
    response.status = e.status;
    response.error = e;
    setDocumentError(response);
  }
  (0, _react.useEffect)(() => {
    if (loaded) {
      setDocumentResults(false);
      executeQuery();
    } else {
      setLoaded(true);
    }
  }, [limit, start, orderBy, controlledRefresh]);
  (0, _react.useEffect)(() => {
    if (controlledDocument) {
      if (start > 0) {
        setStart(0);
      } else {
        executeQuery();
      }
    }
  }, [controlledDocument]);
  return {
    documentError,
    updateDocument,
    changeOrder,
    changeLimits,
    controlledDocument,
    limit,
    start,
    loading,
    rowCount,
    onRefresh,
    documentResults,
    setDocumentResults,
    setControlledRefresh,
    controlledRefresh
  };
}