"use strict";

exports.__esModule = true;
exports.useTDBDocuments = void 0;
var _react = _interopRequireWildcard(require("react"));
var _utils = require("./utils");
var _queryTemplates = require("./queryTemplates");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const useTDBDocuments = woqlClient => {
  const [error, setError] = (0, _react.useState)(false);
  const [loading, setLoading] = (0, _react.useState)(false);

  // bool|Array
  const [documentClasses, setDocumentClasses] = (0, _react.useState)(false);

  // bool|Object
  const [perDocumentCount, setPerDocument] = (0, _react.useState)(false);
  // bool|Number 
  const [totalDocumentCount, setTotalDocumentCount] = (0, _react.useState)(false);

  // bool|Object
  //the  default value is null and false if it will be failed
  //start status null 
  //after the call can be an object or false
  const [documentTablesConfig, setDocumentTablesConfig] = (0, _react.useState)(null);

  // bool|Object
  const [selectedDocument, setSelectedDocument] = (0, _react.useState)(false);
  // bool|Object
  const [frames, setFrames] = (0, _react.useState)(false);

  // store the state of formData  entered by the user
  const [formData, setFormData] = (0, _react.useState)();

  //get all the Document Classes (no abstract or subdocument)
  //improve performance with check last commit
  async function getDocumentClasses() {
    try {
      // to be review I'm adding get table config here
      if (woqlClient) {
        setLoading(true);
        setError(false);
        const dataProduct = woqlClient.db();
        // the list of classes
        const classDocumentsResult = await woqlClient.getClassDocuments(dataProduct);
        const classDocumentOrder = (0, _utils.sortAlphabetically)(classDocumentsResult, true);
        setDocumentClasses(classDocumentOrder);
      }
    } catch (err) {
      setError(err.data || {
        message: err.message
      });
      console.log("Error in init woql while getting classes of data product", err.message);
    } finally {
      setLoading(false);
    }
  }

  // count the number of document I need this in 
  // docHome and query builder
  // I need to reload the class too
  async function getDocumentNumbers() {
    try {
      setLoading(true);
      setError(false);
      const dataProduct = woqlClient.db();
      // I need to reload because I do not know if this can change
      //let classDocumentOrder
      const classDocumentsResult = await woqlClient.getClassDocuments(dataProduct);
      const classes = (0, _utils.sortAlphabetically)(classDocumentsResult, true);
      if (Array.isArray(classes) && classes.length > 0) {
        const totalQ = (0, _queryTemplates.getTotalNumberOfDocuments)(classes);
        //give me back count with the total documents number and total for classes too
        const totalDocumentCount = await woqlClient.query(totalQ);
        //get the total number
        const getTotal = totalDocumentCount.bindings[0].Count["@value"];
        delete totalDocumentCount.bindings[0].Count;
        setTotalDocumentCount(getTotal);
        //pass the count per class
        setPerDocument(totalDocumentCount.bindings[0]);
      }
      setDocumentClasses(classes);
    } catch (err) {
      setError(err.data || {
        message: err.message
      });
      console.log("Error in init woql while getting classes of data product", err.message);
    } finally {
      setLoading(false);
    }
  }
  function getGraphqlTablesConfig() {
    if (woqlClient) {
      setLoading(true);
      // create a  new client instance copying all the settings
      const clientCopy = woqlClient.copy();
      clientCopy.connectionConfig.api_extension = 'api/';
      // I need to remove the team name in the url
      // this call is for the cloud-api
      if (clientCopy.connectionConfig.baseServer) {
        clientCopy.connectionConfig.server = clientCopy.connectionConfig.baseServer;
      }
      const baseUrl = clientCopy.connectionConfig.branchBase("tables");
      clientCopy.sendCustomRequest("GET", baseUrl).then(result => {
        setDocumentTablesConfig(result);
      }).catch(err => {
        setError(err.data || {
          message: err.message
        });
        console.log(err);
        setDocumentTablesConfig(false);
      }).finally(setLoading(false));
    }
  }
  function getDocumentFrames() {
    if (woqlClient) {
      setLoading(true);
      woqlClient.getSchemaFrame().then(res => {
        setFrames(res);
      }).catch(err => {
        setError(err.data || {
          message: err.message
        });
      }).finally(setLoading(false));
    }
  }
  async function createDocument(jsonDocument) {
    try {
      setLoading(true);
      const res = await woqlClient.addDocument(jsonDocument);
      //return the new document id
      return res;
    } catch (err) {
      setFormData(jsonDocument);
      setError(err.data || {
        message: err.message
      });
    } finally {
      setLoading(false);
    }
  }
  async function getSelectedDocument(documentId) {
    try {
      setLoading(true);
      setError(false);
      const params = {
        id: documentId
      };
      const res = await woqlClient.getDocument(params);
      setSelectedDocument(res);
    } catch (err) {
      setError(err.data || {
        message: err.message
      });
    } finally {
      setLoading(false);
    }
  }
  async function getDocumentById(documentId) {
    try {
      setLoading(true);
      setError(false);
      const params = {
        id: documentId
      };
      const res = await woqlClient.getDocument(params);
      return res;
    } catch (err) {
      setError(err.data || {
        message: err.message
      });
    } finally {
      setLoading(false);
    }
  }

  // delete documents
  async function deleteDocument(documentId) {
    try {
      setLoading(true);
      setError(false);
      const params = {
        id: documentId
      };
      let commitMsg = `Deleting document ${documentId}`;
      const res = await woqlClient.deleteDocument(params, null, commitMsg);
      return true;
    } catch (err) {
      setError(err.data || {
        message: err.message
      });
    } finally {
      setLoading(false);
    }
  }
  async function updateDocument(jsonDocument) {
    try {
      setLoading(true);
      setError(false);
      let commitMsg = `Updating document ${jsonDocument["@id"]}`;
      // pass create:true 
      await woqlClient.updateDocument(jsonDocument, {}, null, commitMsg, false, false, false, true);
      return true;
    } catch (err) {
      //display conflict
      setSelectedDocument(jsonDocument);
      setError(err.data || {
        message: err.message
      });
    } finally {
      setLoading(false);
    }
  }
  return {
    setError,
    formData,
    selectedDocument,
    getSelectedDocument,
    getDocumentById,
    deleteDocument,
    createDocument,
    updateDocument,
    getDocumentNumbers,
    getDocumentFrames,
    loading,
    getDocumentClasses,
    error,
    perDocumentCount,
    totalDocumentCount,
    documentClasses,
    getGraphqlTablesConfig,
    documentTablesConfig,
    frames
  };
};
exports.useTDBDocuments = useTDBDocuments;