"use strict";

exports.__esModule = true;
exports.useTDBWOQLQuery = useTDBWOQLQuery;
var _react = _interopRequireWildcard(require("react"));
var _terminusdbClient = _interopRequireDefault(require("@terminusdb/terminusdb-client"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const WOQL = _terminusdbClient.default.WOQL;
function useTDBWOQLQuery(woqlClient, query, results, queryLimit, queryStart, order, total) {
  const [limit, setLimit] = (0, _react.useState)(queryLimit || 0);
  const [start, setStart] = (0, _react.useState)(queryStart || 0);
  const [orderBy, setOrderBy] = (0, _react.useState)(order || false);
  const [rowCount, setRowCount] = (0, _react.useState)();
  const [result, setResult] = (0, _react.useState)(results);
  const [loading, setLoading] = (0, _react.useState)(false);
  const [woql, setWOQL] = (0, _react.useState)(query || false);
  const [loaded, setLoaded] = (0, _react.useState)(false);
  const [commitMsg, setCommitMsg] = (0, _react.useState)();
  const [refresh, setRefresh] = (0, _react.useState)(0);
  const docQuery = q => {
    if (q.containsUpdate()) return q;
    let wrapper = WOQL.query();
    if (limit) wrapper.limit(limit);
    if (start) wrapper.start(start);
    if (orderBy) wrapper.order_by(...orderBy);
    return wrapper.and(q);
  };
  const changeOrder = ord => {
    if (JSON.stringify(orderBy) != JSON.stringify(ord)) {
      setOrderBy(ord);
      setStart(0);
    }
  };
  const onRefresh = () => {
    setRefresh(refresh + 1);
  };

  /*
  * change the limit and the start-page
  */
  const changeLimits = (l, s) => {
    let ll = parseInt(l) || 0;
    let ss = parseInt(s) || 0;
    if (ll != limit) {
      setLimit(ll);
    }
    if (ss != start) setStart(ss);
  };
  const updateQuery = (nwoql, commitMsg) => {
    setWOQL(nwoql);
    setCommitMsg(commitMsg);
  };
  const executeQuery = async () => {
    //I run only if the db is setted 
    //this is important or throw an error
    if (woql && woqlClient.db()) {
      setLoading(true);
      let tstart = Date.now();
      let q = docQuery(woql);
      try {
        const response = await woqlClient.query(q, commitMsg);
        //maybe I can do the count query only the first time
        //the only thing it doesn't work if in the middle time we add another item
        if (!woql.containsUpdate()) {
          const countResult = await executeCountQuery();
          setRowCount(countResult);
        }
        processSuccessfulResult(response, tstart);
      } catch (err) {
        processErrorResult(err, tstart);
      } finally {
        setLoading(false);
      }
    }
  };
  const executeCountQuery = () => {
    let q = WOQL.count("v:Count", woql);
    return woqlClient.query(q).then(cresult => {
      return cresult && cresult.bindings && cresult.bindings.length ? cresult.bindings[0]['Count']['@value'] : 0;
    });
  };
  function attachMetadata(metadata, stime) {
    metadata.start = stime;
    metadata.end = new Date();
    metadata.duration = metadata.end - stime;
    if (typeof metadata.bindings != "undefined") {
      metadata.rows = metadata.bindings ? metadata.bindings.length : 0;
      metadata.columns = metadata.bindings && metadata.bindings[0] ? metadata.bindings[0].length : 0;
    }
  }
  function processSuccessfulResult(response, stime) {
    if (response) {
      attachMetadata(response, stime);
      response.status = 200;
      setResult(response);
    }
  }

  /*
   * I have to review the error in interceptor
   */
  function processErrorResult(e, stime) {
    let response = {};
    attachMetadata(response, stime);
    response.status = e.status;
    response.error = e;
    setResult(response);
  }
  (0, _react.useEffect)(() => {
    if (loaded) {
      executeQuery();
    } else {
      setLoaded(true);
    }
  }, [limit, start, orderBy, refresh]);

  //run query is for query panel
  (0, _react.useEffect)(() => {
    if (woql) {
      if (start > 0) {
        setStart(0);
      } else {
        executeQuery();
      }
    }
  }, [woql]);
  return {
    updateQuery,
    changeOrder,
    changeLimits,
    woql,
    result,
    limit,
    start,
    loading,
    rowCount,
    onRefresh
  };
}