import React, { useState, useEffect, useMemo } from "react";
import { AdvancedSearch, TDBReactTable } from '@terminusdb/terminusdb-react-table';
import { useTDBGraphqlQuery } from '../hook/useTDBGraphqlQuery';
import { Tab, Tabs, Button, Alert, Container, ProgressBar } from 'react-bootstrap';
import { GraphqlQueryView } from "./GraphqlQueryViewer";
import { format } from 'graphql-formatter';
import Accordion from 'react-bootstrap/Accordion';
import { RiDeleteBin7Line, RiEdit2Fill } from "react-icons/ri";
import { HiOutlineDocument } from "react-icons/hi";

//to be review
export const DocumentsGraphqlTable = ({
  gqlQuery,
  apolloClient,
  tableConfig,
  type,
  onRowClick,
  onViewButtonClick,
  onEditButtonClick,
  onDeleteButtonClick,
  showGraphqlTab: _showGraphqlTab = true
}) => {
  if (!tableConfig) return '';
  const query = gqlQuery; //gql`${querystr}`
  const [advSearchFields, setAdvFields] = useState(false);
  const [queryToDisplay, setQueryTodisplay] = useState(false);
  if (!query) return "";
  const tablesColumnsConfig = tableConfig.tablesColumnsConfig[type] || [];
  const {
    setError,
    callGraphqlServer,
    error,
    changeOrders,
    changeLimits,
    changeFilters,
    setAdvancedFilters,
    orderBy,
    filterBy,
    queryFilters,
    queryOrders,
    limit,
    start,
    loading,
    rowCount,
    documentResults: data,
    extractedData,
    hiddenColumnsArr,
    setHiddenColumns
  } = useTDBGraphqlQuery(apolloClient, query, type, {
    limit: 10,
    start: 0,
    tableConfigObj: tablesColumnsConfig
  });
  let extractedResults = extractedData || [];
  useEffect(() => {
    if (type) {
      callGraphqlServer(10, 0, {}, false);
      const queryStr = query.loc.source.body;
      setQueryTodisplay(format(queryStr));
      setAdvFields(tableConfig.advancedSearchObj[type]);
    }
  }, [type]);
  function onRowClickCall(row) {
    if (onRowClick) {
      const rowTmp = row && row.original ? {
        label: row.original.name,
        id: row.original.fullID
      } : {};
      onRowClick(rowTmp);
    }
  }
  const deleteAction = (evt, row) => {
    evt.stopPropagation();
    if (onDeleteButtonClick) {
      const rowTmp = row && row.original ? {
        label: row.original.name,
        id: row.original.fullID
      } : {};
      onDeleteButtonClick(rowTmp);
    }
  };
  const viewAction = (evt, row) => {
    evt.stopPropagation();
    if (onViewButtonClick) {
      const rowTmp = row && row.original ? {
        label: row.original.name,
        id: row.original.fullID
      } : {};
      onViewButtonClick(rowTmp);
    }
  };
  const editAction = (evt, row) => {
    evt.stopPropagation();
    if (onEditButtonClick) {
      const rowTmp = row && row.original ? {
        label: row.original.name,
        id: row.original.fullID
      } : {};
      onEditButtonClick(rowTmp);
    }
  };
  const getActionButtons = props => {
    const invFullId = props.cell.row; //.original['id']
    //const name = cell.row.original['name']
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
      className: "d-flex justify-content-end mr-4"
    }, onViewButtonClick && /*#__PURE__*/React.createElement(Button, {
      variant: "success",
      size: "sm",
      className: "ml-3",
      title: `view document`,
      onClick: evt => viewAction(evt, invFullId)
    }, /*#__PURE__*/React.createElement(HiOutlineDocument, null)), onEditButtonClick && /*#__PURE__*/React.createElement(Button, {
      variant: "success",
      size: "sm",
      className: "ml-3",
      title: `edit document`,
      onClick: evt => editAction(evt, invFullId)
    }, /*#__PURE__*/React.createElement(RiEdit2Fill, null)), onDeleteButtonClick && /*#__PURE__*/React.createElement(Button, {
      variant: "danger",
      size: "sm",
      className: "ml-3",
      title: `delete document`,
      onClick: evt => deleteAction(evt, invFullId)
    }, /*#__PURE__*/React.createElement(RiDeleteBin7Line, null))));
  };
  const makeConfig = () => {
    const actionsButttons = {
      Header: "",
      accessor: "__ACTIONS__",
      disableFilters: true,
      disableSortBy: true,
      id: "__ACTIONS__",
      renderer: getActionButtons
    };

    // to be review
    const tableConfigObj = {};
    tableConfigObj.columns = JSON.parse(JSON.stringify(tablesColumnsConfig));
    if (onDeleteButtonClick || onEditButtonClick || onViewButtonClick) {
      tableConfigObj.columns.push(actionsButttons);
    }
    if (onRowClickCall) {
      tableConfigObj.rowClick = onRowClickCall;
    }
    return tableConfigObj;
  };
  const tableConfigObj = useMemo(() => makeConfig(), [tablesColumnsConfig]);
  const errorMessage = error && typeof error === "object" ? JSON.stringify(error, null, 2) : error;
  return /*#__PURE__*/React.createElement("div", null, error && /*#__PURE__*/React.createElement(Alert, {
    onClose: () => setError(false),
    dismissible: true,
    className: "text-break",
    variant: "danger"
  }, "GraphQL query error ", /*#__PURE__*/React.createElement("pre", {
    className: "pre--error"
  }, errorMessage), " "), advSearchFields && /*#__PURE__*/React.createElement(Accordion, {
    className: "mb-4"
  }, /*#__PURE__*/React.createElement(Accordion.Item, {
    eventKey: "0"
  }, /*#__PURE__*/React.createElement(Accordion.Header, null, "Advanced filter"), /*#__PURE__*/React.createElement(Accordion.Body, {
    className: "p-0"
  }, /*#__PURE__*/React.createElement(AdvancedSearch, {
    fields: advSearchFields,
    setFilter: setAdvancedFilters
  })))), loading && /*#__PURE__*/React.createElement(Container, {
    className: "loading-bar-align justify-content-center"
  }, /*#__PURE__*/React.createElement(ProgressBar, {
    message: `Loading ${type} ...`
  })), !loading && /*#__PURE__*/React.createElement(Tabs, {
    defaultActiveKey: "table",
    className: "mb-3"
  }, /*#__PURE__*/React.createElement(Tab, {
    eventKey: "table",
    title: "Result Table"
  }, !loading && Array.isArray(extractedResults) && /*#__PURE__*/React.createElement(TDBReactTable
  // dowloadConfig={{filename:"test.csv",headers:["Author","Commit ID"]}}
  , {
    result: extractedResults,
    freewidth: true,
    config: tableConfigObj,
    hiddenColumnsArr: hiddenColumnsArr,
    setHiddenColumns: setHiddenColumns,
    limit: limit,
    start: start,
    orderBy: orderBy,
    filterBy: filterBy,
    setFilters: changeFilters,
    setLimits: changeLimits,
    setOrder: changeOrders,
    loading: loading,
    totalRows: rowCount
  })), _showGraphqlTab && /*#__PURE__*/React.createElement(Tab, {
    eventKey: "graphql",
    title: "Graphql Query"
  }, /*#__PURE__*/React.createElement("div", null, queryToDisplay && /*#__PURE__*/React.createElement(GraphqlQueryView, {
    queryFilters: queryFilters,
    queryOrders: queryOrders,
    start: start,
    limit: limit,
    queryToDisplay: queryToDisplay
  })))));
};