import React, { useEffect, useState } from "react";
import { Modal, ProgressBar } from 'react-bootstrap';
import * as CONST from "./constants";
import Alert from 'react-bootstrap/Alert';
import { FrameViewer } from "@terminusdb/terminusdb-documents-ui";
import Button from 'react-bootstrap/Button';
import { AiOutlineArrowRight } from "react-icons/ai";
import Card from "react-bootstrap/Card";
import { AiOutlineClose } from "react-icons/ai";

/**
 * 
 * @param {*} clicked document clicked by user to traverse
 * @param {*} setClicked function to store which document has been clicked by user
 * this function is only used in DocumentView & for Traversing via documents
 */
export function onTraverse(documentID, setClicked) {
  if (setClicked) setClicked(documentID);
}
const ShowLinkRoute = ({
  linkArray,
  handleTraverse
}) => {
  let elements = [];
  linkArray.map((link, index) => {
    elements.push( /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement(Button, {
      variant: "link",
      onClick: e => {
        handleTraverse(link);
      }
    }, `${link}`), index !== linkArray.length - 1 && /*#__PURE__*/React.createElement(AiOutlineArrowRight, {
      className: "fw-bold h4 mt-2 "
    })));
  });
  if (linkArray && linkArray.length > 1) {
    return /*#__PURE__*/React.createElement(Card, {
      className: "border bg-dark border-secondary mb-4"
    }, /*#__PURE__*/React.createElement(Card.Header, {
      className: "small fw-bold text-muted"
    }, `Click through below links to traverse through documents ...`), /*#__PURE__*/React.createElement(Card.Body, null, elements));
  }
  return /*#__PURE__*/React.createElement("div", null);
};
//__KITTY
export const TraverseDocumentLinks = ({
  show,
  onHide,
  clicked,
  getDocumentById,
  frames
}) => {
  const [documentID, setDocumentID] = useState(false);
  const [type, setType] = useState(false);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(false);
  const [result, setResult] = useState(false);

  // document tarverse array
  const [linkArray, setLinkArray] = useState([]);
  useEffect(() => {
    if (clicked) {
      setDocumentID(clicked);
    }
  }, [clicked]);
  function removeDocumentIDFromLinkArray(setLinkArray) {
    // clear array on close
    setLinkArray([]);
  }
  const getDocument = async documentID => {
    if (!getDocumentById) return;
    try {
      setLoading(true);
      const result = await getDocumentById(documentID);
      setResult(result);
    } catch (err) {
      setError(err.message);
    }
  };
  useEffect(() => {
    if (documentID) {
      getDocument(documentID);
      let extractedType = documentID.substring(0, documentID.indexOf("/"));
      setType(extractedType);
      let tempArray = linkArray;
      if (tempArray.includes(documentID)) {
        //tempArray.filter(arr => arr !== documentID)
        let elemsToDelete = tempArray.length - 1 - tempArray.indexOf(documentID);
        tempArray.splice(tempArray.length - elemsToDelete, elemsToDelete);
      } else tempArray.push(documentID);
      setLinkArray(tempArray);
    }
  }, [documentID]);
  function handleClose(e) {
    removeDocumentIDFromLinkArray(setLinkArray);
    onHide();
  }
  function handleTraverse(documentID) {
    onTraverse(documentID, setDocumentID);
  }
  return /*#__PURE__*/React.createElement(Modal, {
    show: show,
    onHide: handleClose,
    size: "md",
    "aria-labelledby": "traverse__document__links",
    centered: true
  }, /*#__PURE__*/React.createElement(Modal.Header, {
    className: " w-100"
  }, /*#__PURE__*/React.createElement(Modal.Title, {
    id: "traverse__document__links",
    className: "text-success h6 w-100"
  }, /*#__PURE__*/React.createElement("strong", {
    className: "text-success"
  }, /*#__PURE__*/React.createElement("span", {
    className: "mr-1 h6 fst-italic"
  }, CONST.VIEW_DOCUMENT, ":"), /*#__PURE__*/React.createElement("span", {
    className: "fw-bolder h6"
  }, " ", documentID, " ")), /*#__PURE__*/React.createElement(Button, {
    className: " ms-auto btn btn-sm bg-transparent text-light border-0 float-right",
    title: "Close",
    onClick: handleClose
  }, /*#__PURE__*/React.createElement(AiOutlineClose, null)))), /*#__PURE__*/React.createElement(Modal.Body, {
    style: {
      minHeight: "500px",
      height: "auto"
    },
    className: "p-4"
  }, error && /*#__PURE__*/React.createElement(Alert, {
    variant: "danger",
    className: "mr-3"
  }, error), loading || !frames && !type && /*#__PURE__*/React.createElement(ProgressBar, {
    message: `Fetching ${documentID} ...`
  }), /*#__PURE__*/React.createElement(ShowLinkRoute, {
    linkArray: linkArray,
    handleTraverse: handleTraverse
  }), type && frames && result && /*#__PURE__*/React.createElement(FrameViewer, {
    frame: frames,
    type: type,
    mode: CONST.VIEW_DOCUMENT,
    formData: result,
    hideSubmit: true,
    onTraverse: handleTraverse
  })));
};